pub struct FailoverConfig {
pub failover_on: Vec<String>,
pub retry_limit: u32,
}Expand description
Configuration for which error categories should trigger failover.
Fields
failover_on: Vec<String>Error categories that should trigger failover to a backup provider.
retry_limit: u32Maximum retries on the primary provider before failing over.